@@ -25,7 +25,7 @@ function()
 
 			rdcom <- paste("dialog.MS.", sepch, "()",sep="")
 		
-			eval(parse(text=rdcom), envir=.GlobalEnv)
+			eval(parse(text=rdcom), envir=as.environment("e1"))
 		tkdestroy(tf)
 		
 	}
